#include <math.h>
#include <stdio.h>

#include "GrowingWindow.h"
#include "TrigonometricPolynomialSlidingWindow.h"

int main()
{
  // new growing window approximation (used to model the segments)
  GrowingWindow *gw = GrowingWindow_create(4);
  // new sliding window approximation (used for segmentation)
  TrigonometricPolynomialSlidingWindow *sw = TrigonometricPolynomialSlidingWindow_create(2, 10);

  int i;
  for (i = 0; i < 1e6; i++)
  {
    // generate time series data
    double y = sin(i / 10.0);

    // update approximation
    TrigonometricPolynomialSlidingWindow_update(sw, y);
    GrowingWindow_update(gw, y);

    double os[3] = {0,0,0};

    TrigonometricPolynomialSlidingWindow_getCoefficients(sw, os);
    double slope = os[1];
    double curve = os[2];
    int segLen = GrowingWindow_getNumSamples(gw);

    // check coefficients of sliding window to detect local maxima
    // and size of current growing window to avoid short segments
    if (fabs(slope) < 0.01 && curve < -0.0045 && segLen > 10)
    {
      // display information about current segment
      double og[5] = {0,0,0,0,0};
      GrowingWindow_getOrthogonalCoefficients(gw, og);
      printf("Segment at %i: avg=%lf, slope=%f, curve=%f,...\n", (i - 15), og[0], og[1], og[2]);
      // reset growing window approximation at start of new segment
      GrowingWindow_reset(gw);
    }

    // restart sliding window approximation to avoid numerical problems
    if (i % 1000 == 0)
      TrigonometricPolynomialSlidingWindow_restart(sw);
  }
}
