#include <iostream>
#include <cmath>

#include "GrowingWindow.hpp"
#include "TrigonometricPolynomialSlidingWindow.hpp"

using namespace std;

int main()
{
  // new growing window approximation (used to model the segments)
  GrowingWindow gw(4);
  // new sliding window approximation (used for segmentation)
  TrigonometricPolynomialSlidingWindow sw(2, 10);

  for (int i = 0; i < 1e6; i++)
  {
    // generate time series data
    double y = sin(i / 10.0);

    // update approximation
    sw.update(y);
    gw.update(y);

    std::vector< std::vector<double> > os = sw.getCoefficients();
    double slope = os[0][1];
    double curve = os[0][2];
    int segLen = gw.getNumSamples();

    // check coefficients of sliding window to detect local maxima
    // and size of current growing window to avoid short segments
    if (fabs(slope) < 0.01 && curve < -0.0045 && segLen > 10)
    {
      // display information about current segment
      std::vector<double> og = gw.getOrthogonalCoefficients();
      std::cout << "Segment at " << (i - 15) << ": avg=" << og[0] << ", slope="
          << og[1] << ", curve=" << og[2] << ", ..." << std::endl;

      // reset growing window approximation at start of new segment
      gw.reset();
    }

    // restart sliding window approximation to avoid numerical problems
    if (i % 1000 == 0)
      sw.restart();
  }
}
