import java.io.*;
import java.util.Arrays;

public class SegmentationExample {

    public static void main(String[] args) throws IOException {

        // new growing window approximation (used to model the segments)
        GrowingWindow gw = new GrowingWindow(4);
        // new sliding window approximation (used for segmentation)
        SlidingWindow sw = new SlidingWindow(2, 10);

        for (int i = 0; i < 1e6; i++) {

            // generate time series data
            double y = Math.sin(i / 10d);

            // update approximation
            sw.update(y);
            gw.update(y);

            double[] os = sw.getOrthogonalCoefficients();
            double slope = os[1];
            double curve = os[2];
            int segLen = gw.getNumSamples();

            // check coefficients of sliding window to detect local maxima
            // and size of current growing window to avoid short segments
            if (Math.abs(slope) < 0.01 && curve < -0.0045 && segLen > 10) {

                // display information about current segment
                double[] og = gw.getOrthogonalCoefficients();
                System.out.println("Segment at " + (i - 15) + ": avg=" + og[0]
                    + ", slope=" + og[1] + ", curve=" + og[2] + ", ...");

                // reset growing window approximation at start of new segment
                gw.reset();
            }

            // restart sliding window approximation to avoid numerical problems
            if (i % 1e3 == 0) {
                sw.restart();
            }
        }
    }
}
