#!/usr/bin/python
import sys
import getopt
import math

from libpyffal import *

def segmentationExample():
    gw = GrowingWindow(4)
    sw = OrthogonalPolynomialSlidingWindow(2,10)

    for i in range(0, int(1e6)):
        # generate time series data
        y = math.sin(i / 10.0)
        # update approximation
        sw.update(y)
        gw.update(y)
        os = sw.getOrthogonalCoefficients()
        slope = os[1];
        curve = os[2];
        segLen = gw.getNumSamples()

        # check coefficients of sliding window to detect local maxima
        # and size of current growing window to avoid short segments
        if (abs(slope) < 0.01 and curve < -0.0045 and segLen > 10):
            # display information about current segment
            og = gw.getOrthogonalCoefficients()
            print "Segment at " + str(int(i - 15)) + ": avg=" + str(og[0]) + ", slope="             + str(og[1]) + ", curve=" + str(og[2]) + ", ..."
            # reset growing window approximation at start of new segment
            gw.reset()

        # restart sliding window approximation to avoid numerical problems
        if (i % 1000 == 0):
          sw.restart()

def main():
    # parse command line options
    try:
        opts, args = getopt.getopt(sys.argv[1:], "h", ["help"])
    except getopt.error, msg:
        print msg
        print "for help use --help"
        sys.exit(2)
    # process options
    for o, a in opts:
        if o in ("-h", "--help"):
            print __doc__
            sys.exit(0)
    # process arguments
    for arg in args:
        process(arg) # process() is defined elsewhere
    # do the work
    segmentationExample()

if __name__ == "__main__":
    main()