/**
 *  @file   TrigonometricPolynomialSlidingWindow.h
 *  @brief  TrigonometricPolynomialSlidingWindow class C wrapper header
 *  @date   17.09.2013
 *  @author Peter Rudolph
 *
 *  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES\n
 *  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF\n
 *  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR\n
 *  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES\n
 *  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN\n
 *  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF\n
 *  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.\n
 *
 *  @copyright Intelligent Embedded Systems, University of Kassel, 2013. All rights reserved.
 *  @license This library is released under <a href="http://www.gnu.org/licenses/lgpl-3.0.de.html">LGPLv3</a>.
 */

#ifndef __TRIGONOMETRICPOLYNOMIALSLIDINGWINDOW_H__
#define __TRIGONOMETRICPOLYNOMIALSLIDINGWINDOW_H__

#ifdef __cplusplus
extern "C" {
#endif

/**
 *  @brief Struct representing TrigonometricPolynomialSlidingWindow handle
 */
typedef struct TrigonometricPolynomialSlidingWindow TrigonometricPolynomialSlidingWindow;

/**
 *  @brief Create TrigonometricPolynomialSlidingWindow Handle
 *  @param degree Degree of approximated polynomial
 *  @param windowsize Size of sliding window
 *  @return Pointer to TrigonometricPolynomialSlidingWindow Handle
 */
TrigonometricPolynomialSlidingWindow* TrigonometricPolynomialSlidingWindow_create(int degree, int windowsize);

/**
 *  @brief Reset TrigonometricPolynomialSlidingWindow Approximation
 *  @param sw Pointer to TrigonometricPolynomialSlidingWindow Handle
 */
void TrigonometricPolynomialSlidingWindow_restart(TrigonometricPolynomialSlidingWindow* sw);

/**
 *  @brief Update TrigonometricPolynomialSlidingWindow Approximation
 *  @param sw Pointer to TrigonometricPolynomialSlidingWindow Handle
 *  @param y Value to update with.
 */
void TrigonometricPolynomialSlidingWindow_update(TrigonometricPolynomialSlidingWindow* sw, double y);

/**
*	@brief Evaluate polynomial at x.
*	@param sw Pointer to TrigonometricPolynomialSlidingWindow handle.
*	@param x Value polynomial is evaluated at.
*	@return Evaluation at x.
*/
double TrigonometricPolynomialSlidingWindow_eval(TrigonometricPolynomialSlidingWindow* sw, double x);

/**
 *  @brief Get coefficients
 *  @param sw Pointer to TrigonometricPolynomialSlidingWindow Handle
 *  @param coefficients Pointer to double array which is filled by function itself, size must be degree + 1
 */
void TrigonometricPolynomialSlidingWindow_getCoefficients(TrigonometricPolynomialSlidingWindow* sw, double *re_coeff, double* im_coeff);

/**
*	@brief Get approximation error.
*	@param sw Pointer to TrigonometricPolynomialSlidingWindow handle
*	@return Approximation error
*/
double TrigonometricPolynomialSlidingWindow_getApproximationError(TrigonometricPolynomialSlidingWindow* sw);

/**
 *  @brief Delete TrigonometricPolynomialSlidingWindow Handle
 *  @param sw Pointer to TrigonometricPolynomialSlidingWindow Handle
 */
void TrigonometricPolynomialSlidingWindow_delete(TrigonometricPolynomialSlidingWindow* sw);

#ifdef __cplusplus
}
#endif

#endif /*__TRIGONOMETRICPOLYNOMIALSLIDINGWINDOW_H__*/