/**
 *  @file   GrowingWindowWrapper.cpp
 *  @brief  GrowingWindow class C wrapper implementation
 *  @date   17.09.2013
 *  @author Peter Rudolph
 *
 *  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES\n
 *  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF\n
 *  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR\n
 *  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES\n
 *  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN\n
 *  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF\n
 *  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.\n
 *
 *  @copyright Intelligent Embedded Systems, University of Kassel, 2013. All rights reserved.
 *  @license This library is released under <a href="http://www.gnu.org/licenses/lgpl-3.0.de.html">LGPLv3</a>.
 */

#include "GrowingWindow.h"
#include "GrowingWindow.hpp"

#include <iostream>
#include <cmath>
#include <cstring>

extern "C" 
{

GrowingWindow *GrowingWindow_create(int degree)
{
  return new GrowingWindow(degree);
}

void GrowingWindow_reset(GrowingWindow *gw)
{
  gw->reset();
}

void GrowingWindow_update(GrowingWindow *gw, double y)
{
  gw->update(y);
}

double GrowingWindow_eval(GrowingWindow* gw, double x)
{
    return gw->eval(x);
}

int GrowingWindow_getNumSamples(GrowingWindow *gw)
{
  return gw->getNumSamples();
}

void GrowingWindow_getOrthogonalCoefficients(GrowingWindow *gw, double *coefficients)
{
  std::vector<double> coeffs = gw->getOrthogonalCoefficients();
  memcpy(coefficients, &coeffs[0], coeffs.size() * sizeof(double));
}

double GrowingWindow_getApproximationError(GrowingWindow* gw)
{
    return gw->getApproximationError();
}

double GrowingWindow_getExtremumPosition(GrowingWindow* gw)
{
    return gw->getExtremumPosition();
}

void GrowingWindow_delete(GrowingWindow *gw)
{
  delete gw;
}

}