/**
 *  @file   OrthogonalPolynomialSlidingWindowWrapper.cpp
 *  @brief  OrthogonalPolynomialSlidingWindowWrapper class C wrapper implementation
 *  @date   17.09.2013
 *  @author Peter Rudolph
 *
 *  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES\n
 *  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF\n
 *  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR\n
 *  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES\n
 *  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN\n
 *  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF\n
 *  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.\n
 *
 *  @copyright Intelligent Embedded Systems, University of Kassel, 2013. All rights reserved.
 *  @license This library is released under <a href="http://www.gnu.org/licenses/lgpl-3.0.de.html">LGPLv3</a>.
 */

#include "OrthogonalPolynomialSlidingWindow.h"
#include "OrthogonalPolynomialSlidingWindow.hpp"

#include <iostream>
#include <cmath>
#include <cstring>

extern "C" 
{

OrthogonalPolynomialSlidingWindow* OrthogonalPolynomialSlidingWindow_create(int degree, int windowsize)
{
  return new OrthogonalPolynomialSlidingWindow(degree, windowsize);
}

void OrthogonalPolynomialSlidingWindow_restart(OrthogonalPolynomialSlidingWindow *sw)
{
  sw->restart();
}

void OrthogonalPolynomialSlidingWindow_update(OrthogonalPolynomialSlidingWindow *sw, double y)
{
  sw->update(y);
}

double OrthogonalPolynomialSlidingWindow_eval(OrthogonalPolynomialSlidingWindow* sw, double x)
{
    return sw->eval(x);
}

void OrthogonalPolynomialSlidingWindow_getOrthogonalCoefficients(OrthogonalPolynomialSlidingWindow *sw, double *coefficients)
{
  std::vector<double> coeffs = sw->getOrthogonalCoefficients();
  memcpy(coefficients, &coeffs[0], coeffs.size() * sizeof(double));
}

double OrthogonalPolynomialSlidingWindow_getApproximationError(OrthogonalPolynomialSlidingWindow* sw)
{
    return sw->getApproximationError();
}

double OrthogonalPolynomialSlidingWindow_getExtremumPosition(OrthogonalPolynomialSlidingWindow* sw)
{
    return sw->getExtremumPosition();
}

void OrthogonalPolynomialSlidingWindow_delete(OrthogonalPolynomialSlidingWindow *sw) 
{
  delete sw;
}

}