/**
 *  @file   PythonBindings.cpp
 *  @brief  libffal Python bindings implementation
 *  @date   17.09.2013
 *  @author Peter Rudolph
 *
 *  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES\n
 *  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF\n
 *  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR\n
 *  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES\n
 *  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN\n
 *  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF\n
 *  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.\n
 *
 *  @copyright Intelligent Embedded Systems, University of Kassel, 2013. All rights reserved.
 *  @license This library is released under <a href="http://www.gnu.org/licenses/lgpl-3.0.de.html">LGPLv3</a>.
 */
#include <boost/python.hpp>
#include <boost/python/suite/indexing/vector_indexing_suite.hpp>
#include "GrowingWindow.hpp"
#include "OrthogonalPolynomialSlidingWindow.hpp"
#include "TrigonometricPolynomialSlidingWindow.hpp"

using namespace boost::python;

/**
  *  @brief The python binding
  */
BOOST_PYTHON_MODULE(libpyffal)
{
  // 1D Array/List
  class_<std::vector<double> >("VectorConverter1D")
	.def(vector_indexing_suite<std::vector<double> >() );
  
  // 2D Array/List
  class_<std::vector< std::vector<double> > >("VectorConverter2D")
	.def(vector_indexing_suite<std::vector< std::vector<double> > >() );
  
  class_<GrowingWindow>("GrowingWindow", init<int>())
    .def("reset", &GrowingWindow::reset)
    .def("update", &GrowingWindow::update)
    .def("eval", &GrowingWindow::eval)
    .def("getNumSamples", &GrowingWindow::getNumSamples)
    .def("getOrthogonalCoefficients", &GrowingWindow::getOrthogonalCoefficients)
    .def("getApproximationError", &GrowingWindow::getApproximationError)
    .def("getExtremumPosition", &GrowingWindow::getExtremumPosition)
  ;

  class_<OrthogonalPolynomialSlidingWindow>("OrthogonalPolynomialSlidingWindow", init<int,int>())
    .def("restart", &OrthogonalPolynomialSlidingWindow::restart)
    .def("update", &OrthogonalPolynomialSlidingWindow::update)
    .def("eval", &OrthogonalPolynomialSlidingWindow::eval)
    .def("getOrthogonalCoefficients", &OrthogonalPolynomialSlidingWindow::getOrthogonalCoefficients)
    .def("getApproximationError", &OrthogonalPolynomialSlidingWindow::getApproximationError)
    .def("getExtremumPosition", &OrthogonalPolynomialSlidingWindow::getExtremumPosition)
  ;

  class_<TrigonometricPolynomialSlidingWindow>("TrigonometricPolynomialSlidingWindow", init<int,int>())
    .def("restart", &TrigonometricPolynomialSlidingWindow::restart)
    .def("update", &TrigonometricPolynomialSlidingWindow::update)
    .def("eval", &TrigonometricPolynomialSlidingWindow::eval)
    .def("getCoefficients", &TrigonometricPolynomialSlidingWindow::getCoefficients)
    .def("getApproximationError", &TrigonometricPolynomialSlidingWindow::getApproximationError)
  ;
}