/**
 *  @file   TrigonometricPolynomialSlidingWindowWrapper.cpp
 *  @brief  TrigonometricPolynomialSlidingWindowWrapper class C wrapper implementation
 *  @date   17.09.2013
 *  @author Peter Rudolph
 *
 *  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES\n
 *  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF\n
 *  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR\n
 *  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES\n
 *  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN\n
 *  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF\n
 *  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.\n
 *
 *  @copyright Intelligent Embedded Systems, University of Kassel, 2013. All rights reserved.
 *  @license This library is released under <a href="http://www.gnu.org/licenses/lgpl-3.0.de.html">LGPLv3</a>.
 */

#include "TrigonometricPolynomialSlidingWindow.h"
#include "TrigonometricPolynomialSlidingWindow.hpp"

#include <iostream>
#include <cmath>
#include <cstring>

extern "C"
{

TrigonometricPolynomialSlidingWindow* TrigonometricPolynomialSlidingWindow_create(int degree, int windowsize)
{
  return new TrigonometricPolynomialSlidingWindow(degree, windowsize);
}

void TrigonometricPolynomialSlidingWindow_restart(TrigonometricPolynomialSlidingWindow *sw)
{
  sw->restart();
}

void TrigonometricPolynomialSlidingWindow_update(TrigonometricPolynomialSlidingWindow *sw, double y)
{
  sw->update(y);
}

double TrigonometricPolynomialSlidingWindow_eval(TrigonometricPolynomialSlidingWindow* sw, double x)
{
    return sw->eval(x);
}

void TrigonometricPolynomialSlidingWindow_getCoefficients(TrigonometricPolynomialSlidingWindow *sw, double *re_coeff, double* im_coeff)
{
  std::vector< std::vector<double> > re_im_coeffs = sw->getCoefficients();
  std::vector<double> re_coeffs = re_im_coeffs[0];
  std::vector<double> im_coeffs = re_im_coeffs[1];
  memcpy(re_coeff, &re_coeffs[0], re_coeffs.size() * sizeof(double));
  memcpy(im_coeff, &im_coeffs[0], im_coeffs.size() * sizeof(double));
}

double TrigonometricPolynomialSlidingWindow_getApproximationError(TrigonometricPolynomialSlidingWindow* sw)
{
    return sw->getApproximationError();
}

void TrigonometricPolynomialSlidingWindow_delete(TrigonometricPolynomialSlidingWindow *sw) 
{
  delete sw;
}

}